From 924125b8eae1dbe9e057dd620c2572ef5955d779 Mon Sep 17 00:00:00 2001
From: Geoffrey Thomas <geofft@ldpreload.com>
Date: Mon, 17 Jun 2013 00:51:44 -0700
Subject: [PATCH] Add a v3 mode that includes the architecture for
 Pre-Install-Pkgs input.

---
 apt-pkg/deb/dpkgpm.cc |    8 +++++---
 apt-pkg/deb/dpkgpm.h  |    2 +-
 doc/apt.conf.5.xml    |    5 +++--
 3 files changed, 9 insertions(+), 6 deletions(-)

diff --git a/apt-pkg/deb/dpkgpm.cc b/apt-pkg/deb/dpkgpm.cc
index 3bc31dc..732c58a 100644
--- a/apt-pkg/deb/dpkgpm.cc
+++ b/apt-pkg/deb/dpkgpm.cc
@@ -242,9 +242,9 @@ bool pkgDPkgPM::Remove(PkgIterator Pkg,bool Purge)
 // ---------------------------------------------------------------------
 /* This is part of the helper script communication interface, it sends
    very complete information down to the other end of the pipe.*/
-bool pkgDPkgPM::SendV2Pkgs(FILE *F)
+bool pkgDPkgPM::SendV2Pkgs(FILE *F, unsigned int Version)
 {
-   fprintf(F,"VERSION 2\n");
+   fprintf(F,"VERSION %u\n", Version);
    
    /* Write out all of the configuration directives by walking the 
       configuration tree */
@@ -280,6 +280,8 @@ bool pkgDPkgPM::SendV2Pkgs(FILE *F)
       pkgDepCache::StateCache &S = Cache[I->Pkg];
       
       fprintf(F,"%s ",I->Pkg.Name());
+      if (Version >= 3)
+	 fprintf(F,"%s ",I->Pkg.Arch());
       // Current version
       if (I->Pkg->CurrentVer == 0)
 	 fprintf(F,"- ");
@@ -404,7 +406,7 @@ bool pkgDPkgPM::RunScriptsWithPkgs(const char *Cnf)
 	 }
       }
       else
-	 SendV2Pkgs(F);
+	 SendV2Pkgs(F, Version);
 
       fclose(F);
       
diff --git a/apt-pkg/deb/dpkgpm.h b/apt-pkg/deb/dpkgpm.h
index aab39f6..2aa0556 100644
--- a/apt-pkg/deb/dpkgpm.h
+++ b/apt-pkg/deb/dpkgpm.h
@@ -79,7 +79,7 @@ class pkgDPkgPM : public pkgPackageManager
 
    // Helpers
    bool RunScriptsWithPkgs(const char *Cnf);
-   bool SendV2Pkgs(FILE *F);
+   bool SendV2Pkgs(FILE *F, unsigned int Version);
    void WriteHistoryTag(std::string const &tag, std::string value);
 
    // apport integration
diff --git a/doc/apt.conf.5.xml b/doc/apt.conf.5.xml
index be1d7ad..39f47ec 100644
--- a/doc/apt.conf.5.xml
+++ b/doc/apt.conf.5.xml
@@ -691,8 +691,9 @@ DPkg::Pre-Install-Pkgs {"/usr/sbin/dpkg-preconfigure --apt";};
 
      <para>Version 2 of this protocol dumps more information, including the 
      protocol version, the APT configuration space and the packages, files
-     and versions being changed. Version 2 is enabled by setting 
-     <literal>DPkg::Tools::options::cmd::Version</literal> to 2. <literal>cmd</literal> is a
+     and versions being changed. Version 3 also adds the architecture of the
+     package to the output. These versions can be enabled by setting
+     <literal>DPkg::Tools::options::cmd::Version</literal> to 2 or 3. <literal>cmd</literal> is a
      command given to <literal>Pre-Install-Pkgs</literal>.</para></listitem>
      </varlistentry>
 
-- 
1.7.10.4

